@@ -1,4 +1,4 @@
-#! /bin/bash
+#! /bin/sh
 
 cd ${0%/*}
 export PATH=$PWD:${PATH}
@@ -12,6 +12,10 @@ newns tomoyo_capability_test
 newns tomoyo_signal_test
 newns tomoyo_network_test
 newns tomoyo_argv0_test
+newns tomoyo_env_test
+newns tomoyo_new_file_test
+newns tomoyo_new_capability_test
+newns tomoyo_new_network_test
 echo
 echo
 echo
@@ -24,3 +28,14 @@ newns tomoyo_capability_test | grep -vF OK | grep -F '('
 newns tomoyo_signal_test | grep -vF OK | grep -F '('
 newns tomoyo_network_test | grep -vF OK | grep -F '('
 newns tomoyo_argv0_test | grep -vF OK | grep -F '('
+newns tomoyo_env_test | grep -vF OK | grep -F '('
+echo
+echo
+echo
+echo "Testing policy I/O.  (Only ERRORS are reported)"
+newns tomoyo_bprm_test | grep -vF OK
+newns tomoyo_cond_test | grep -vF OK
+newns ccs_policy_io_test | grep -vF OK
+newns tomoyo_new_file_test | grep -vF OK
+newns tomoyo_new_capability_test | grep -vF OK
+newns tomoyo_new_network_test | grep -vF OK
